formKey property
E
formKey
final
The enum key that identifies this field in the form entity.
Implementation
final E formKey;
The enum key that identifies this field in the form entity.
final E formKey;