validator property
Standard TextFormField validator.
Runs on the raw string value. Bloc-driven validation errors are displayed through the field decoration.
Implementation
final FormFieldValidator<String>? validator;
Standard TextFormField validator.
Runs on the raw string value. Bloc-driven validation errors are displayed through the field decoration.
final FormFieldValidator<String>? validator;