inputFormatters property
Input formatters applied before the value reaches the bloc.
Implementation
final List<TextInputFormatter> inputFormatters;
Input formatters applied before the value reaches the bloc.
final List<TextInputFormatter> inputFormatters;