showClearButton property
Whether to show a clear button when the field has text.
Ignored when obscureText is true.
Implementation
final bool showClearButton;
Whether to show a clear button when the field has text.
Ignored when obscureText is true.
final bool showClearButton;