suffix property
Widget placed at the end of the field (suffix icon area).
Overridden by the unique-field progress indicator when a check is running.
Implementation
final Widget? suffix;
Widget placed at the end of the field (suffix icon area).
Overridden by the unique-field progress indicator when a check is running.
final Widget? suffix;