textDirection property
Explicit text direction.
When omitted, direction is detected from the current text.
Implementation
final TextDirection? textDirection;
Explicit text direction.
When omitted, direction is detected from the current text.
final TextDirection? textDirection;