disablePopWhileSubmitting property
Whether the secondary button should be disabled while the form submits.
Implementation
final bool disablePopWhileSubmitting;
Whether the secondary button should be disabled while the form submits.
final bool disablePopWhileSubmitting;