disableRegisterWhenInvalid property

bool disableRegisterWhenInvalid
final

Whether the submit button should be disabled when validation errors exist.

Defaults to false to avoid deadlocking forms that use FormValidationMode.onSubmit.

Implementation

final bool disableRegisterWhenInvalid;