onPressed property
Called when the button is tapped while idle.
If null, the button calls submit on the nearest ancestor
BlocxFormWidgetState.
Implementation
final VoidCallback? onPressed;
Called when the button is tapped while idle.
If null, the button calls submit on the nearest ancestor
BlocxFormWidgetState.
final VoidCallback? onPressed;