spacing property
Horizontal spacing between the loading indicator and the label text.
Defaults to 8.0.
Implementation
final double spacing;
Horizontal spacing between the loading indicator and the label text.
Defaults to 8.0.
final double spacing;