state property
BlocxFormState<F, E>
state
final
The current form state.
Used to determine button loading, disabled state, and label text.
Implementation
final BlocxFormState<F, E> state;
The current form state.
Used to determine button loading, disabled state, and label text.
final BlocxFormState<F, E> state;