autoCloseBloc property

bool get autoCloseBloc

Whether bloc is closed when this state is disposed. Defaults to true.

Set to false when the bloc outlives this widget (e.g. it is provided by an ancestor BlocProvider).

Implementation

bool get autoCloseBloc => true;