isValid property
bool
get
isValid
Whether the current form state has no validation errors.
Implementation
bool get isValid => bloc.state.isValid;
Whether the current form state has no validation errors.
bool get isValid => bloc.state.isValid;