AnimatedInfiniteListOptions class

Inheritance

Constructors

AnimatedInfiniteListOptions({ScrollBehavior? scrollBehavior, bool reverse = false, bool animateAtStart = false, EdgeInsets? padding, Duration? animationDuration, int loadMoreTriggerItemDistance = 2, AlwaysScrollableScrollPhysics? scrollPhysics, bool shrinkWrap = false, Axis scrollDirection = Axis.vertical})
const

Properties

animateAtStart bool
final
animationDuration Duration?
final
hashCode int
The hash code for this object.
no setterinherited
loadMoreTriggerItemDistance int
finalinherited
padding EdgeInsets?
finalinherited
reverse bool
Shared across all collection widgets.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollBehavior ScrollBehavior?
finalinherited
scrollDirection Axis
finalinherited
scrollPhysics AlwaysScrollableScrollPhysics?
finalinherited
shrinkWrap bool
finalinherited

Methods

asOrThrow<T extends CollectionOptions>() → T
inherited
assertCorrectType(CollectionWidgetStateType type) → void
Runtime safety: ensure the options instance matches the widget state type.
inherited
copyWith({bool? reverse, bool? animateAtStart, EdgeInsets? padding, Duration? animationDuration, int? bottomLoadingTriggerItemDistance, int? loadMoreTriggerItemDistance, AlwaysScrollableScrollPhysics? scrollPhysics, bool? shrinkWrap}) AnimatedInfiniteListOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited