AnimatedSliverInfiniteList<Entity extends BlocxBaseEntity> class

Inheritance

Constructors

AnimatedSliverInfiniteList({Key? key, required AnimatedSliverInfiniteListOptions options, required List<Entity> items, required Widget itemBuilder(BuildContext context, Entity item), required BlocxInfiniteListBloc bloc, required Widget loading, required Widget empty, Widget separatorBuilder(BuildContext context, int index)?, VoidCallback? refreshOnSwipe, VoidCallback? loadBottomData, VoidCallback? loadTopData, ScrollController? scrollController, Widget? loadMoreWidgetBuilder(BuildContext context, bool isLoadingMore)?, Widget? refreshWidgetBuilder(BuildContext context, double swipeRefreshHeight)?, bool? isLoading, bool? isEmpty, Widget? sliverTop, Widget? sliverBottom})
const

Properties

bloc → BlocxInfiniteListBloc
final
empty Widget
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool?
final
isLoading bool?
final
itemBuilder Widget Function(BuildContext context, Entity item)
final
items List<Entity>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadBottomData VoidCallback?
final
loading Widget
final
loadMoreWidgetBuilder Widget? Function(BuildContext context, bool isLoadingMore)?
final
loadTopData VoidCallback?
final
options AnimatedSliverInfiniteListOptions
final
refreshOnSwipe VoidCallback?
final
refreshWidgetBuilder Widget? Function(BuildContext context, double swipeRefreshHeight)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
final
separatorBuilder Widget Function(BuildContext context, int index)?
final
sliverBottom Widget?
final
sliverTop Widget?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() AnimatedSliverBlocxInfiniteListState<Entity>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited