isLoading property
bool
get
isLoading
Whether the collection is currently loading its initial data.
Implementation
bool get isLoading => _bloc.state is BlocxCollectionStateLoading;
Whether the collection is currently loading its initial data.
bool get isLoading => _bloc.state is BlocxCollectionStateLoading;