scrollController property
The active scroll controller used by the rendered collection widget.
Implementation
ScrollController? scrollController;
The active scroll controller used by the rendered collection widget.
ScrollController? scrollController;