CollectionSettings class
Settings used by BlocxCollectionWidgetState to choose a collection widget.
Constructors
- CollectionSettings({required CollectionWidgetStateType type, required CollectionOptions options})
- Creates collection settings.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → CollectionOptions
-
The options matching type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → CollectionWidgetStateType
-
The collection display type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited