SliverInfiniteGridOptions class

Inheritance

Constructors

SliverInfiniteGridOptions({ScrollBehavior? scrollBehavior, bool shrinkWrap = false, bool reverse = false, AlwaysScrollableScrollPhysics? scrollPhysics, int loadMoreTriggerItemDistance = 2, required int crossAxisCount, double childAspectRatio = 1.0, double mainAxisSpacing = 0.0, double crossAxisSpacing = 0.0, Axis scrollDirection = Axis.vertical, bool? primary, double? cacheExtent, double anchor = 0.0, Clip clipBehavior = Clip.hardEdge, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual, EdgeInsets? gridPadding, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, SemanticIndexCallback? semanticIndexCallback, int semanticIndexOffset = 0})
const

Properties

addAutomaticKeepAlives bool
--------- Grid semantic & keep-alive ----------
final
addRepaintBoundaries bool
final
addSemanticIndexes bool
final
anchor double
final
cacheExtent double?
final
childAspectRatio double
finalinherited
clipBehavior Clip
final
crossAxisCount int
Used to build the grid delegate (or consumed by sliver grid).
finalinherited
crossAxisSpacing double
finalinherited
gridPadding EdgeInsets?
Padding applied around the grid sliver.
final
hashCode int
The hash code for this object.
no setterinherited
keyboardDismissBehavior ScrollViewKeyboardDismissBehavior
final
loadMoreTriggerItemDistance int
finalinherited
mainAxisSpacing double
finalinherited
primary bool?
--------- CustomScrollView inputs ----------
final
reverse bool
Shared across all collection widgets.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollBehavior ScrollBehavior?
finalinherited
scrollDirection Axis
finalinherited
scrollPhysics AlwaysScrollableScrollPhysics?
finalinherited
semanticIndexCallback SemanticIndexCallback?
final
semanticIndexOffset int
final
shrinkWrap bool
finalinherited

Methods

asOrThrow<T extends CollectionOptions>() → T
inherited
assertCorrectType(CollectionWidgetStateType type) → void
Runtime safety: ensure the options instance matches the widget state type.
inherited
copyWith({bool? reverse, AlwaysScrollableScrollPhysics? scrollPhysics, int? bottomLoadingTriggerItemDistance, int? loadMoreTriggerItemDistance, int? crossAxisCount, double? childAspectRatio, double? mainAxisSpacing, double? crossAxisSpacing, Axis? scrollDirection, bool? primary, double? cacheExtent, double? anchor, Clip? clipBehavior, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, EdgeInsets? gridPadding, bool? addAutomaticKeepAlives, bool? addRepaintBoundaries, bool? addSemanticIndexes, SemanticIndexCallback? semanticIndexCallback, int? semanticIndexOffset}) SliverInfiniteGridOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited