SliverInfiniteListOptions class

Inheritance

Constructors

SliverInfiniteListOptions({ScrollBehavior? scrollBehavior, bool reverse = false, bool shrinkWrap = false, EdgeInsets? padding, int loadMoreTriggerItemDistance = 2, AlwaysScrollableScrollPhysics? scrollPhysics, Axis scrollDirection = Axis.vertical, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, SemanticIndexCallback? semanticIndexCallback, int semanticIndexOffset = 0})
const

Properties

addAutomaticKeepAlives bool
final
addRepaintBoundaries bool
final
addSemanticIndexes bool
final
hashCode int
The hash code for this object.
no setterinherited
loadMoreTriggerItemDistance int
finalinherited
padding EdgeInsets?
finalinherited
reverse bool
Shared across all collection widgets.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollBehavior ScrollBehavior?
finalinherited
scrollDirection Axis
finalinherited
scrollPhysics AlwaysScrollableScrollPhysics?
finalinherited
semanticIndexCallback SemanticIndexCallback?
final
semanticIndexOffset int
final
shrinkWrap bool
finalinherited

Methods

asOrThrow<T extends CollectionOptions>() → T
inherited
assertCorrectType(CollectionWidgetStateType type) → void
Runtime safety: ensure the options instance matches the widget state type.
inherited
copyWith({bool? reverse, EdgeInsets? padding, int? bottomLoadingTriggerItemDistance, int? loadMoreTriggerItemDistance, AlwaysScrollableScrollPhysics? scrollPhysics, bool? addAutomaticKeepAlives, bool? addRepaintBoundaries, bool? addSemanticIndexes, SemanticIndexCallback? semanticIndexCallback, int? semanticIndexOffset}) SliverInfiniteListOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited