decoration property
Optional base InputDecoration.
When provided, the decoration is used as the base decoration. Runtime values such as bloc-driven errorText and suffix loading indicators are still merged into it.
Implementation
final InputDecoration? decoration;