filled property
Whether the filled text field variant uses a filled background.
This only affects TextFieldType.filled. Outlined and underlined variants are not filled by default.
Implementation
final bool filled;
Whether the filled text field variant uses a filled background.
This only affects TextFieldType.filled. Outlined and underlined variants are not filled by default.
final bool filled;