onPressed property
Called when the button is tapped while idle.
If null, the button will call submit on the nearest ancestor
BlocxFormWidgetState instead.
Implementation
final VoidCallback? onPressed;
Called when the button is tapped while idle.
If null, the button will call submit on the nearest ancestor
BlocxFormWidgetState instead.
final VoidCallback? onPressed;