state property

BlocxFormState<dynamic, Enum> state
final

The current form state, used to determine whether the button should be disabled and which label to display.

Implementation

final BlocxFormState state;