state property
The current form state, used to determine whether the button should be disabled and which label to display.
Implementation
final BlocxFormState state;
The current form state, used to determine whether the button should be disabled and which label to display.
final BlocxFormState state;