Whether bloc is closed when this state is disposed. Defaults to true.
true
Set to false when the bloc outlives this widget (e.g. it is provided by an ancestor BlocProvider).
false
BlocProvider
bool get autoCloseBloc => true;