isValid property
bool
get
isValid
Whether the current form state passes all validation rules.
Implementation
bool get isValid => bloc.state.isValid;
Whether the current form state passes all validation rules.
bool get isValid => bloc.state.isValid;