keys property

List<E> get keys

The list of field enum values that have managed TextEditingControllers.

Used by applyInitialDataToForm to hydrate controllers on init. Return all values whose fields are created via textField.

Implementation

List<E> get keys;