AnimatedSliverInfiniteListOptions class
- Inheritance
-
- Object
- CollectionOptions
- ListOptions
- AnimatedSliverInfiniteListOptions
Constructors
- AnimatedSliverInfiniteListOptions({ScrollBehavior? scrollBehavior, bool shrinkWrap = false, bool reverse = false, EdgeInsets? padding, AlwaysScrollableScrollPhysics? scrollPhysics, int loadMoreTriggerItemDistance = 2, Axis scrollDirection = Axis.vertical, bool initialAnimation = true, Duration insertDuration = const Duration(milliseconds: 300), Duration deleteDuration = const Duration(milliseconds: 300), AnimatedChildBuilder? insertAnimation, AnimatedChildBuilder? deleteAnimation})
-
const
Properties
- deleteAnimation → AnimatedChildBuilder?
-
final
- deleteDuration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialAnimation → bool
-
final
- insertAnimation → AnimatedChildBuilder?
-
final
- insertDuration → Duration
-
final
- loadMoreTriggerItemDistance → int
-
finalinherited
- padding → EdgeInsets?
-
finalinherited
- reverse → bool
-
Shared across all collection widgets.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollBehavior → ScrollBehavior?
-
finalinherited
- scrollDirection → Axis
-
finalinherited
- scrollPhysics → AlwaysScrollableScrollPhysics?
-
finalinherited
- shrinkWrap → bool
-
finalinherited
Methods
-
asOrThrow<
T extends CollectionOptions> () → T -
inherited
-
assertCorrectType(
CollectionWidgetStateType type) → void -
Runtime safety: ensure the options instance matches the widget state type.
inherited
-
copyWith(
{bool? reverse, EdgeInsets? padding, AlwaysScrollableScrollPhysics? scrollPhysics, int? bottomLoadingTriggerItemDistance, int? loadMoreTriggerItemDistance, bool? initialAnimation, Duration? insertDuration, Duration? deleteDuration, AnimatedChildBuilder? insertAnimation, AnimatedChildBuilder? deleteAnimation}) → AnimatedSliverInfiniteListOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited