BlocxCollectionWidgetState<W extends BlocxCollectionWidget<P>, T extends BlocxBaseEntity, P> class abstract

Inheritance

Properties

autoDisposeBloc bool
no setter
bloc → BlocxCollectionBloc<T, P>
no setter
colorScheme ColorScheme
no setterinherited
context BuildContext
The location in the tree where this widget builds.
no setterinherited
deleteAnimation → AnimatedChildBuilder?
no setter
generateBloc → BlocxCollectionBloc<T, P>
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
no setterinherited
insertAnimation → AnimatedChildBuilder?
no setter
isLoading bool
no setter
isSearching bool
no setter
loadOnInit bool
no setter
managerCubit → ScreenManagerCubit
The ScreenManagerCubit that drives this screen's side-effects.
no setter
mounted bool
Whether this State object is currently in a tree.
no setterinherited
payload → P?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
getter/setter pair
scrollControllerProvider ScrollController?
no setter
searchingText String
no setter
settings CollectionSettings
no setter
textTheme TextTheme
no setterinherited
theme ThemeData
no setterinherited
topBottomAndListSpacing double
no setter
widget → W
The current configuration.
no setterinherited
width double
no setterinherited
wrapInScaffold bool
Whether the body should be wrapped in a Scaffold.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addToList(T item, {int index = 0}) → dynamic
blocListener(BuildContext context, BlocxCollectionState<T> state) → void
bottomWidget(BuildContext context, BlocxCollectionState<T> state) Widget?
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
collectionWidget(BuildContext context, BlocxCollectionState<T> state) Widget
collectionWrapperBuilder(BuildContext context, BlocxCollectionState<T> state) Widget
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
decorateScaffold(Widget scaffold) Widget
Hook to decorate the scaffold returned by scaffoldWidget.
inherited
deleteMultipleItems(List<T> items) → dynamic
deselectMultipleItems(List<T> items) → dynamic
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant W oldWidget) → void
Called whenever the widget configuration changes.
inherited
displaySnackBar(BuildContext context, String message, String? title, BlocXSnackbarType snackbarType) → void
Shows a BlocxSnackBar with the given parameters.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
emptyWidget(BuildContext context, BlocxCollectionState<T> state) Widget
errorWidget(BuildContext context, ScreenManagerCubitStateDisplayErrorPage state) Widget
Builds the full-page error widget for ScreenManagerCubitStateDisplayErrorPage.
inherited
errorWidgetByErrorCode(BuildContext context, ScreenManagerCubitStateDisplayErrorPageByErrorCode state) Widget
Builds the full-page error widget for ScreenManagerCubitStateDisplayErrorPageByErrorCode.
inherited
initState() → void
Called when this object is inserted into the tree.
itemBuilder(BuildContext context, T item) Widget
loadingWidget(BuildContext context, BlocxCollectionState<T> state) Widget
loadMoreWidgetBuilder(BuildContext context, bool isLoadingMore) Widget?
loadNextPage() → void
mainWidget(BuildContext context, ScreenManagerCubitState state) Widget
The primary screen content.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSelectionChanged(BuildContext context, SelectionChangedData<T> selectionData) → void
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
refreshData() → void
refreshWidgetBuilder(BuildContext context, double swipeRefreshHeight) Widget?
scaffoldWidget(BuildContext context, Widget body) Widget
Wraps body in a Scaffold.
inherited
scrollToItem(T item, {bool highlightItem = false}) → void
separatorBuilder(BuildContext context, int index) Widget
setScrollController() → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
sliverBottomWidget(BuildContext context, BlocxCollectionState<T> state) Widget?
sliverTopWidget(BuildContext context, BlocxCollectionState<T> state) Widget?
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
topWidget(BuildContext context, BlocxCollectionState<T> state) Widget?
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited