InfiniteGridOptions class
- Inheritance
-
- Object
- CollectionOptions
- GridOptions
- InfiniteGridOptions
Constructors
- InfiniteGridOptions({ScrollBehavior? scrollBehavior, bool shrinkWrap = false, bool reverse = false, AlwaysScrollableScrollPhysics? scrollPhysics, int loadMoreTriggerItemDistance = 2, required int crossAxisCount, double childAspectRatio = 1.0, double mainAxisSpacing = 0.0, double crossAxisSpacing = 0.0, Axis scrollDirection = Axis.vertical, EdgeInsets? padding})
-
const
Properties
- childAspectRatio → double
-
finalinherited
- crossAxisCount → int
-
Used to build the grid delegate (or consumed by sliver grid).
finalinherited
- crossAxisSpacing → double
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- loadMoreTriggerItemDistance → int
-
finalinherited
- mainAxisSpacing → double
-
finalinherited
- padding → EdgeInsets?
-
final
- reverse → bool
-
Shared across all collection widgets.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollBehavior → ScrollBehavior?
-
finalinherited
- scrollDirection → Axis
-
finalinherited
- scrollPhysics → AlwaysScrollableScrollPhysics?
-
finalinherited
- shrinkWrap → bool
-
finalinherited
Methods
-
asOrThrow<
T extends CollectionOptions> () → T -
inherited
-
assertCorrectType(
CollectionWidgetStateType type) → void -
Runtime safety: ensure the options instance matches the widget state type.
inherited
-
copyWith(
{bool? reverse, AlwaysScrollableScrollPhysics? scrollPhysics, int? bottomLoadingTriggerItemDistance, int? loadMoreTriggerItemDistance, int? crossAxisCount, double? childAspectRatio, double? mainAxisSpacing, double? crossAxisSpacing, EdgeInsets? padding, bool? shrinkWrap}) → InfiniteGridOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited